summaryrefslogtreecommitdiff
path: root/sd/source/ui
diff options
context:
space:
mode:
Diffstat (limited to 'sd/source/ui')
-rw-r--r--sd/source/ui/func/fuchar.cxx2
-rw-r--r--sd/source/ui/func/futempl.cxx4
-rw-r--r--sd/source/ui/view/drtxtob1.cxx2
-rw-r--r--sd/source/ui/view/drviews2.cxx2
4 files changed, 5 insertions, 5 deletions
diff --git a/sd/source/ui/func/fuchar.cxx b/sd/source/ui/func/fuchar.cxx
index 6b5cad68a973..a1c69e25b041 100644
--- a/sd/source/ui/func/fuchar.cxx
+++ b/sd/source/ui/func/fuchar.cxx
@@ -85,7 +85,7 @@ void FuChar::DoExecute( SfxRequest& rReq )
if ( pBrushItem )
{
- SvxBackgroundColorItem aBackColorItem( pBrushItem->GetColor(), EE_CHAR_BKGCOLOR );
+ SvxColorItem aBackColorItem( pBrushItem->GetColor(), EE_CHAR_BKGCOLOR );
aOtherSet.ClearItem( SID_ATTR_BRUSH_CHAR );
aOtherSet.Put( aBackColorItem );
}
diff --git a/sd/source/ui/view/drtxtob1.cxx b/sd/source/ui/view/drtxtob1.cxx
index 2c92f0b66d06..4292978d85cf 100644
--- a/sd/source/ui/view/drtxtob1.cxx
+++ b/sd/source/ui/view/drtxtob1.cxx
@@ -95,7 +95,7 @@ namespace
case SID_ATTR_CHAR_BACK_COLOR:
{
- SvxBackgroundColorItem pBackgroundItem(aColor, EE_CHAR_BKGCOLOR);
+ SvxColorItem pBackgroundItem(aColor, EE_CHAR_BKGCOLOR);
pArgs->Put(pBackgroundItem);
break;
}
diff --git a/sd/source/ui/view/drviews2.cxx b/sd/source/ui/view/drviews2.cxx
index 01120a842903..094cbb806d2b 100644
--- a/sd/source/ui/view/drviews2.cxx
+++ b/sd/source/ui/view/drviews2.cxx
@@ -3781,7 +3781,7 @@ void DrawViewShell::ExecChar( SfxRequest &rReq )
case SID_ATTR_CHAR_BACK_COLOR:
if( rReq.GetArgs() )
{
- const SvxBackgroundColorItem* pItem = rReq.GetArg<SvxBackgroundColorItem>(SID_ATTR_CHAR_BACK_COLOR);
+ const SvxColorItem* pItem = rReq.GetArg<SvxColorItem>(SID_ATTR_CHAR_BACK_COLOR);
if (pItem)
{
aNewAttr.Put(*pItem);
diff --git a/sd/source/ui/func/futempl.cxx b/sd/source/ui/func/futempl.cxx
index aeb9251e3002..e75a18b74782 100644
--- a/sd/source/ui/func/futempl.cxx
+++ b/sd/source/ui/func/futempl.cxx
@@ -385,12 +385,12 @@ void FuTemplate::DoExecute( SfxRequest& rReq )
if (eFamily == SfxStyleFamily::Pseudo)
{
SfxItemSet aTempSet(*pOutSet);
/* Extract SvxBrushItem out of set and insert SvxBackgroundColorItem */
const SvxBrushItem* pBrushItem = aTempSet.GetItem<SvxBrushItem>( SID_ATTR_BRUSH_CHAR );
if ( pBrushItem )
{
- SvxBackgroundColorItem aBackColorItem(pBrushItem->GetColor(), EE_CHAR_BKGCOLOR);
+ SvxColorItem aBackColorItem(pBrushItem->GetColor(), EE_CHAR_BKGCOLOR);
aTempSet.ClearItem( EE_CHAR_BKGCOLOR );
aTempSet.Put( aBackColorItem );
}
@@ -385,12 +385,12 @@ void FuTemplate::DoExecute( SfxRequest& rReq )
{
SfxItemSet aTempSet(*pOutSet);
- /* Extract SvxBrushItem out of set and insert SvxBackgroundColorItem */
+ /* Extract SvxBrushItem out of set and insert SvxColorItem */
const SvxBrushItem* pBrushItem = aTempSet.GetItem<SvxBrushItem>( SID_ATTR_BRUSH_CHAR );
if ( pBrushItem )